@@ -1,6 +1,13 @@
 package Vend::Parser;
 
-# $Id: Parser.pm,v 1.11 1998/01/31 05:21:43 mike Exp $
+# $Id: Parser.pm,v 1.4 2000/02/06 01:50:33 mike Exp $
+#
+#
+# Copyright 1996 Gisle Aas. All rights reserved.
+#
+# Modifications for MiniVend Copyright 1997-2000 by Michael J. Heins
+# <mikeh@minivend.com>
+#
 
 =head1 NAME
 
@@ -97,7 +104,7 @@ Copyright 1997-1998 Mike Heins.
 =head1 AUTHOR
 
 Gisle Aas <aas@sn.no>
-Modified by Mike Heins <mikeh@iac.net>  
+Modified by Mike Heins <mikeh@minivend.com>  
 
 =cut
 
@@ -106,7 +113,7 @@ use strict;
 
 use HTML::Entities ();
 use vars qw($VERSION);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 
 sub new
@@ -139,11 +146,12 @@ sub eof
 	shift->parse(undef);
 }
 
+use vars qw/$Find_tag/;
 
 sub parse
 {
 	my $self = shift;
-	my $buf = \ $self->{'_buf'};
+	my $buf = \ $self->{_buf};
 	unless (defined $_[0]) {
 		# signals EOF (assume rest is plain text)
 		$self->text($$buf) if length $$buf;
@@ -151,80 +159,42 @@ sub parse
 		return $self;
 	}
 	$$buf .= $_[0];
+#	$Find_tag = qr{^([^[<]+)};
+#::logDebug("no_html_parse=$Vend::Cfg->{Pragma}{no_html_parse}");
+#	$Find_tag    = qr{^([^\[]+)} 
+#		 if $Vend::Cfg->{Pragma}{no_html_parse};
+	$Find_tag	= $Vend::Cfg->{Pragma}{no_html_parse}
+				?  qr{^([^[]+)}
+				:  qr{^([^[<]+)}
+				;
+#::logDebug("no_html_parse=$Vend::Cfg->{Pragma}{no_html_parse} Find_tag=$Find_tag");
 
+	my $eaten;
 	# Parse html text in $$buf.  The strategy is to remove complete
 	# tokens from the beginning of $$buf until we can't deside whether
 	# it is a token or not, or the $$buf is empty.
 	while (1) {  # the loop will end by returning when text is parsed
 		# First we try to pull off any plain text (anything before a "<" char)
-		if ($$buf =~ s|^([^\[]+)||) {
-			unless (length $$buf) {
-				my $text = $1;
-				# At the end of the buffer, we should not parse white space
-				# but leave it for parsing on the next round.
-				if ($text =~ s|(\s+)$||) {
-					$$buf = $1;
-				# Same treatment for chopped up entites.
-				} elsif ($text =~ s/(&(?:(?:\#\d*)?|\w*))$//) {
-					$$buf = $1;
-				};
-				$self->text($text);
-				return $self;
-			} else {
-				$self->text($1);
-			}
-		# Netscapes buggy comments are easy to handle
-		} elsif ($self->{'_netscape_comment'} && $$buf =~ m|^(<!--)|) {
-			if ($$buf =~ s|^<!--(.*?)-->||s) {
-				$self->comment($1);
-			} else {
-				return $self;  # must wait until we see the end of it
-			}
-		# Then, markup declarations (usually either <!DOCTYPE...> or a comment)
-#		} elsif ($$buf =~ s|^(\[!)||) {
-#			my $eaten = $1;
-#			my $text = '';
-#			my @com = ();  # keeps comments until we have seen the end
-#			# Eat text and beginning of comment
-#			while ($$buf =~ s|^(([^>]*?)--)||) {
-#				$eaten .= $1;
-#				$text .= $2;
-#				# Look for end of comment
-#				if ($$buf =~ s|^((.*?)--)||s) {
-#					$eaten .= $1;
-#					push(@com, $2);
-#				} else {
-#					# Need more data to get all comment text.
-#					$$buf = $eaten . $$buf;
-#					return $self;
-#				}
-#			}
-#			# Can we finish the tag
-#			if ($$buf =~ s|^([^>]*)>||) {
-#				$text .= $1;
-#				$self->declaration($text) if $text =~ /\S/;
-#				# then tell about all the comments we found
-#				for (@com) { $self->comment($_); }
-#			} else {
-#				$$buf = $eaten . $$buf;  # must start with it all next time
-#				return $self;
-#			}
-		} elsif ($$buf =~ s|^\[/||) {
-			# end tag
-			if ($$buf =~ s|^\s*([a-z][-a-z0-9._]*)\s*\]||i) {
-				$self->end(lc($1));
-			} elsif ($$buf =~ m|^\s*[a-z]*[-a-z0-9._]*\s*$|i) {
-				$$buf = "\[/" . $$buf;  # need more data to be sure
-				return $self;
-			} else {
-				# it is plain text after all
-				$self->text($$buf);
-				$$buf = "";
-			}
+		if ($$buf =~ s/$Find_tag// ) {
+#my $eat = $1;
+#::logDebug("plain eat='$eat'");
+#$self->text($eat);
+			$self->text($1);
+			return $self unless length $$buf;
+		# Find the most common tags
+		} elsif ($$buf =~ s|^(\[([-a-z0-9A-Z_]+)[^"'=\]>]*\])||) {
+#my $tag=$2; my $eat = $1;
+#undef $self->{HTML};
+#::logDebug("tag='$tag' eat='$eat'");
+#$self->start($tag, {}, [], $eat);
+				undef $self->{HTML};
+				$self->start($2, {}, [], $1);
 		# Then, finally we look for a start tag
 		} elsif ($$buf =~ s|^\[||) {
 			# start tag
-			my $eaten = '[';
+			$eaten = '[';
+			$self->{HTML} = 0 if ! defined $self->{HTML};
+#::logDebug("do [ tag");
 
 			# This first thing we must find is a tag name.  RFC1866 says:
 			#   A name consists of a letter followed by letters,
@@ -235,35 +205,56 @@ sub parse
 			#   immediately follow the tag open delimiter `<'.
 			if ($$buf =~ s|^(([a-zA-Z][-a-zA-Z0-9._]*)\s*)||) {
 				$eaten .= $1;
-				my $tag = lc $2;
+
+				my ($tag);
+				my ($nopush, $element);
 				my %attr;
 				my @attrseq;
-
 				my $old;
 
+				$tag = lc $2;
+#::logDebug("tag='$tag' eat='$eaten'");
+
 				# Then we would like to find some attributes
 				#
 				# Arrgh!! Since stupid Netscape violates RCF1866 by
 				# using "_" in attribute names (like "ADD_DATE") of
 				# their bookmarks.html, we allow this too.
-				#while (	$$buf =~ s|^(([a-zA-Z][-a-zA-Z0-9._]*)\s*)|| ) {
 				while (	$$buf =~ s|^(([a-zA-Z][-a-zA-Z0-9._]*)\s*)|| or
-					 	$$buf =~ s|^(([=!<>][=~])\s+)||) {
+					 	$$buf =~ s|^(([=!<>][=~]?)\s+)||                 )
+				{
 					$eaten .= $1;
 					my $attr = lc $2;
+#::logDebug("in parse, eaten=$eaten");
+					$attr =~ s/\.(.*)//
+						and $element = $1;
+						
 					my $val;
-
+					
 					# The attribute might take an optional value (first we
 					# check for an unquoted value)
-					if ($$buf =~ s|(^=\s*([^\"\'\]\s][^\]\s]*)\s*)||) {
+					if ($$buf =~ s~(^=\s*([^\|\"\'\`\]\s][^\]>\s]*)\s*)~~) {
 						$eaten .= $1;
+						next unless defined $attr;
 						$val = $2;
-						HTML::Entities::decode($val);
-					# or quoted by " or '
-					} elsif ($$buf =~ s|(^=\s*([\"\'])(.*?)\2\s*)||s) {
+					# or quoted by " or ' or # or $ or |
+					} elsif ($$buf =~ s~(^=\s*(["\'])(.*?)\2\s*)~~s) {
 						$eaten .= $1;
+						next unless defined $attr;
 						$val = $3;
-						HTML::Entities::decode($val);
+						HTML::Entities::decode($val) if $attr{entities};
+					# or quoted by `` to send to [calc]
+					} elsif ($$buf =~ s~(^=\s*([\`\|])(.*?)\2\s*)~~s) {
+						$eaten .= $1;
+						if    ($2 eq '`') { $val = Vend::Interpolate::tag_calc($3); }
+						elsif ($2 eq '|') {
+								$val = $3;
+								$val =~ s/^\s+//;
+								$val =~ s/\s+$//;
+						}
+						else {
+							die "parse error!";
+						}
 					# truncated just after the '=' or inside the attribute
 					} elsif ($$buf =~ m|^(=\s*)$|s or
 							 $$buf =~ m|^(=\s*[\"\'].*)|s) {
@@ -273,38 +264,54 @@ sub parse
 						# assume attribute with implicit value, but
 						# if not,no value is set and the
 						# eaten value is grown
-# DEBUG
-#Vend::Util::logDebug
-#("Implicit test...")
-#	if ::debug(0x2);
-# END DEBUG
-						($attr,$val) = $self->implicit($tag,$attr);
+						undef $nopush;
+						($attr,$val,$nopush) = $self->implicit($tag,$attr);
 						$old = 1 unless $val;
-# DEBUG
-#Vend::Util::logDebug
-#("old=$old val=$val attr=$attr\n")
-#	if ::debug(0x2);
-# END DEBUG
-					} else {
-# DEBUG
-#Vend::Util::logDebug
-#("Abort attribute parsing, attr='$attr'.\n")
-#	if ::debug(0x2);
-# END DEBUG
-						$old = 1;
+
 					}
 					next if $old;
+					if(! $attr) {
+						$attr->{OLD} = $val if defined $attr;
+						next;
+					}
+					if(defined $element) {
+#::logDebug("Found element: $element val=$val");
+						if(! ref $attr{$attr}) {
+							if ($element =~ /[A-Za-z]/) {
+								$attr{$attr} = { $element => $val };
+							}
+							else {
+								$attr{$attr} = [ ];
+								$attr{$attr}->[$element] = $val;
+							}
+							push (@attrseq, $attr);
+						}
+						elsif($attr{$attr} =~ /ARRAY/) {
+							if($element =~ /\D/) {
+								push @{$attr{$attr}}, $val;
+							}
+							else {
+								$attr{$attr}->[$element] = $val;
+							}
+						}
+						elsif ($attr{$attr} =~ /HASH/) {
+							$attr{$attr}->{$element} = $val;
+						}
+						undef $element;
+						next;
+					}
 					$attr{$attr} = $val;
-					push(@attrseq, $attr);
+					push(@attrseq, $attr) unless $nopush;
 				}
 
-				# At the end there should be a closing "\]"
-				if ($$buf =~ s|^\]||) {
+				# At the end there should be a closing "\] or >"
+				if ($$buf =~ s|^\]|| ) {
 					$self->start($tag, \%attr, \@attrseq, "$eaten]");
 				} elsif ($$buf =~ s|^([^\]\n]+\])||) {
 					$eaten .= $1;
 					$self->start($tag, {}, [], $eaten);
 				} elsif (length $$buf) {
+#::logDebug("eaten $eaten");
 					# Not a conforming start tag, regard it as normal text
 					$self->text($eaten);
 				} else {
@@ -313,65 +320,164 @@ sub parse
 				}
 
 			} elsif (length $$buf) {
+#::logDebug("eaten $eaten");
 				$self->text($eaten);
 			} else {
-				$$buf = $eaten . $$buf;  # need more data to parse
+				$$buf = $eaten;  # need more data to parse
+				return $self;
+			}
+		} elsif ($$buf =~ s|^<||) {
+			# start tag
+			$eaten = '<';
+#::logDebug("do < tag") if ! $Vend::DoneDebug++;
+
+			# This first thing we must find is a tag name.  RFC1866 says:
+			#   A name consists of a letter followed by letters,
+			#   digits, periods, or hyphens. The length of a name is
+			#   limited to 72 characters by the `NAMELEN' parameter in
+			#   the SGML declaration for HTML, 9.5, "SGML Declaration
+			#   for HTML".  In a start-tag, the element name must
+			#   immediately follow the tag open delimiter `<'.
+			if ($$buf =~ s|^(([a-zA-Z][-a-zA-Z0-9._]*)((?:\s+[^>]+)?\s+[mM][Vv]\s*=)\s*)||) {
+#::logDebug("REALLY do < tag") if ! $Vend::DoneDebug++;
+				$eaten .= $1;
+				$self->{HTML} = 1;
+
+				my ($tag, $end_tag);
+				my ($nopush, $element);
+				my %attr;
+				my @attrseq;
+				my $old;
+
+				$end_tag = $2;
+#::logDebug("end_tag='$end_tag' eat='$eaten'");
+				( $$buf =~ s|^((['"])(.*?)\2\s*)||s and $tag = $3 )
+				or
+				( $$buf =~ s|^(([a-zA-Z][-a-zA-Z0-9._]*)\s*)|| and $tag = $2)
+				or ($self->text($eaten), next);
+				$eaten .= $1;
+				if( index($tag, " ") != -1 ) {
+					($tag, $attr{OLD}) = split /\s+/, $tag, 2;
+				}
+#::logDebug("< tag='$tag' eat='$eaten'");
+				$tag = lc $tag;
+
+				# Then we would like to find some attributes
+				#
+				# Arrgh!! Since stupid Netscape violates RCF1866 by
+				# using "_" in attribute names (like "ADD_DATE") of
+				# their bookmarks.html, we allow this too.
+				while (	$$buf =~ s|^(([a-zA-Z][-a-zA-Z0-9._]*)\s*)|| ) {
+					$eaten .= $1;
+#::logDebug("in parse, eaten=$eaten");
+					my $attr = lc $2;
+					$attr =~ s/^mv\.?//
+						or $tag =~ /^urld/
+						or undef $attr;
+					$attr =~ s/\.(.*)//
+						and $element = $1;
+						
+					my $val;
+					
+					# The attribute might take an optional value (first we
+					# check for an unquoted value)
+					if ($$buf =~ s~(^=\s*([^\!\|\@\"\'\`\]\s][^\]>\s]*)\s*)~~) {
+						$eaten .= $1;
+						next unless defined $attr;
+						$val = $2;
+					# or quoted by " or ' or # or $ or |
+					} elsif ($$buf =~ s~(^=\s*(["\'])(.*?)\2\s*)~~s) {
+						$eaten .= $1;
+						next unless defined $attr;
+						$val = $3;
+						HTML::Entities::decode($val) if $attr{entities};
+					# or quoted by `` to send to [calc]
+					} elsif ($$buf =~ s~(^=\s*([\`\|]?)(.*?)\2\s*)~~s) {
+						$eaten .= $1;
+						if    ($2 eq '`') { $val =Vend::Interpolate::tag_calc($4); }
+						elsif ($2 eq '|') {
+								$val = $3;
+								$val =~ s/^\s+//;
+								$val =~ s/\s+$//;
+						}
+						else {
+							die "parse error!";
+						}
+					# truncated just after the '=' or inside the attribute
+					} elsif ($$buf =~ m|^(=\s*)$|s or
+							 $$buf =~ m|^(=\s*[\"\'].*)|s) {
+#::logDebug("Truncated? eaten=$eateni buf=$$buf");
+						$$buf = "$eaten$1";
+						return $self;
+					} 
+
+					if(defined $element) {
+#::logDebug("Found element: $element val=$val");
+						if(! ref $attr{$attr}) {
+							if ($element =~ /[A-Za-z]/) {
+								$attr{$attr} = { $element => $val };
+							}
+							else {
+								$attr{$attr} = [ ];
+								$attr{$attr}->[$element] = $val;
+							}
+							push (@attrseq, $attr);
+						}
+						elsif($attr{$attr} =~ /ARRAY/) {
+							if($element =~ /\D/) {
+								push @{$attr{$attr}}, $val;
+							}
+							else {
+								$attr{$attr}->[$element] = $val;
+							}
+						}
+						elsif ($attr{$attr} =~ /HASH/) {
+							$attr{$attr}->{$element} = $val;
+						}
+						undef $element;
+						next;
+					}
+					$attr{$attr} = $val;
+					push(@attrseq, $attr) unless $nopush;
+				}
+
+				# At the end there should be a closing "\] or >"
+				if ($$buf =~ s|^>|| ) {
+					$self->start($tag, \%attr, \@attrseq, "$eaten>", $end_tag);
+				} elsif (length $$buf) {
+#::logDebug("not conforming, eaten $eaten");
+					# Not a conforming start tag, regard it as normal text
+					$self->text($eaten);
+				} else {
+					$$buf = $eaten;  # need more data to know
+					return $self;
+				}
+
+			} elsif (length $$buf) {
+#::logDebug("eaten $eaten");
+				$self->text($eaten);
+			} else {
+				#$$buf = $eaten;  # need more data to parse
 				return $self;
 			}
 
 		} elsif (length $$buf) {
-			die; # This should never happen
+			::logDebug("remaining: $$buf");
+			die $$buf; # This should never happen
 		} else {
 			# The buffer is empty now
 			return $self;
 		}
+		return $self if $self->{SEND};
 	}
 	$self;
 }
 
-sub parse_file
-{
-	my($self, $file) = @_;
-	no strict 'refs';  # so that a symbol ref as $file works
-	local(*F);
-	unless (ref($file) || $file =~ /^\*[\w:]+$/) {
-		# Assume $file is a filename
-		open(F, $file) || die "Can't open $file: $!";
-		$file = \*F;
-	}
-	my $chunk = '';
-	while(read($file, $chunk, 2048)) {
-		$self->parse($chunk);
-	}
-	close($file);
-	$self->eof;
-}
-
-sub text
-{
-	# my($self, $text) = @_;
-}
-
-sub declaration
-{
-	# my($self, $decl) = @_;
-}
 
 sub comment
 {
 	# my($self, $comment) = @_;
 }
 
-sub start
-{
-	my($self, $tag, $attr, $attrseq, $origtext) = @_;
-	# $attr is reference to a HASH, $attrseq is reference to an ARRAY
-}
-
-sub end
-{
-	my($self, $tag) = @_;
-}
-
 1;
 __END__
